@@ -1,7 +1,7 @@
 use crate::prelude::*;
 use crate::{enums::*, widget::Widget};
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct Frame {
     inner: Widget,
 }
@@ -13,12 +13,7 @@ impl WidgetBase for Frame {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
@@ -31,7 +26,7 @@ impl WidgetBase for Frame {
 
 impl WidgetExt for Frame {}
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct Label {
     inner: Widget,
 }
@@ -42,12 +37,7 @@ impl WidgetBase for Label {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
