@@ -2,7 +2,7 @@ use crate::prelude::*;
 use crate::{enums::*, widget::Widget};
 use wasm_bindgen::JsCast;
 
-#[derive(Clone)]
+#[derive(Debug, Clone)]
 pub struct Image {
     inner: Widget,
 }
@@ -33,12 +33,7 @@ impl WidgetBase for Image {
         crate::group::Group::current_attach(&inner);
         Self { inner }
     }
-    fn default_fill() -> Self {
-        let s = Self::default();
-        s.inner.set_style(Style::Width, "100%");
-        s.inner.set_style(Style::Height, "100%");
-        s
-    }
+
     unsafe fn from_widget(widget: &Widget) -> Self {
         Self {
             inner: widget.clone(),
